@@ -4,6 +4,7 @@
 from .helpers import normalize_space
 from .exceptions import WPNotValidMetadataError
 
+# For now you cannot add custom fields!
 FIELDS = ('ISBN-13', 'Title', 'Authors', 'Publisher', 'Year', 'Language')
 
 
@@ -87,6 +88,18 @@ class Metadata(object):
             raise WPNotValidMetadataError()
         self.clean()
 
+    def empties(self):
+        """
+        Returns the names of empty fields
+        """
+        return [k for k, v in self._content.items() if v == u'' or v == []]
+
+    def metric(self):
+        """
+        Returns the length of the characters that repr the object
+        """
+        return len(repr(self._content))
+
     def _validate(self):
         """
         Validates canonical
@@ -114,6 +127,41 @@ class Metadata(object):
         return '\n'.join((': '.join((f, repr(self._content[f]))) for f
                           in FIELDS)).replace("u''", "").replace("[]", "")
 
+    def __iter__(self):
+        """
+        Define an iterator for the class
+        """
+        for k, v in self._content.items():
+            if k == 'Authors':
+                continue
+            yield k, v
+        for i, a in enumerate(self._content['Authors']):
+            yield 'Author%s' % i, a
+
+    def __len__(self):
+        """
+        Meaningful property for len(metadata object): Sum elements != u''
+        """
+        lenk = len([v for v in self._content.values() if v != u''])
+        lena = len([l for l in self._content.get('Authors') if l != u''])
+        return lenk + lena - 1
+
+    def __eq__(self, other):
+        """
+        When are two of these objects equal?
+        """
+        if self.metric() != other.metric():
+            return False
+        # if self.__len__(self) != self.__len__(other):
+        #     return False
+        qk = all(v == other._content[k] for k, v in self._content.items()
+                 if k != 'Authors')
+        if not qk:
+            return False
+        qa = all(self._content['Authors'][i] == other._content['Authors'][i]
+                 for i in range(len(self._content['Authors'])))
+        return qa
+
 
 def stdmeta(records):
     """
