@@ -29,24 +29,10 @@ class GOOBQuery(WEBQuery):
         # lets us go with the default raw data_checker
         WEBQuery.check_data(self)
 
-    def records(self):
+    def mapper(self, records):
         """
-        Classifies (canonically) the parsed data
+        Mapping canonical <- records
         """
-        # this service uses JSON, so stay with the default parser
-        data = WEBQuery.parse_data(self)
-        try:
-            # put the selected data in records
-            records = data['items'][0]['volumeInfo']
-        except:             # pragma: no cover
-            try:
-                extra = data['stat']
-                logger.debug('WPDataWrongShapeError for % with data %s' %
-                             (self.isbn, extra))
-            except:
-                raise WPDataWrongShapeError(self.isbn)
-            raise WPDataNotFoundError(self.isbn)
-
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
         try:
@@ -67,6 +53,27 @@ class GOOBQuery(WEBQuery):
         # call stdmeta for extra cleanning and validation
         return stdmeta(canonical)
 
+    def records(self):
+        """
+        Classifies (canonically) the parsed data
+        """
+        # this service uses JSON, so stay with the default parser
+        data = WEBQuery.parse_data(self)
+        try:
+            # put the selected data in records
+            records = data['items'][0]['volumeInfo']
+        except:             # pragma: no cover
+            try:
+                extra = data['stat']
+                logger.debug('WPDataWrongShapeError for % with data %s' %
+                             (self.isbn, extra))
+            except:
+                raise WPDataWrongShapeError(self.isbn)
+            raise WPDataNotFoundError(self.isbn)
+
+        # map canonical <- records
+        return self.mapper(records)
+
 
 def query(isbn):
     """
