@@ -28,18 +28,10 @@ class OPENLQuery(WEBQuery):
         # lets us go with the default raw data_checker
         WEBQuery.check_data(self)
 
-    def records(self):
+    def mapper(self, records):
         """
-        Classifies (canonically) the parsed data
+        Mapping canonical <- records
         """
-        # this service uses JSON, so stay with the default parser
-        data = WEBQuery.parse_data(self)
-        try:
-            # put the selected data in records
-            records = data['ISBN:%s' % self.isbn]
-        except:
-            raise WPDataNotFoundError(self.isbn)
-
         # canonical:
         # -> ISBN-13, Title, Authors, Publisher, Year, Language
         try:
@@ -57,6 +49,21 @@ class OPENLQuery(WEBQuery):
         # call stdmeta for extra cleanning and validation
         return stdmeta(canonical)
 
+    def records(self):
+        """
+        Classifies (canonically) the parsed data
+        """
+        # this service uses JSON, so stay with the default parser
+        data = WEBQuery.parse_data(self)
+        try:
+            # put the selected data in records
+            records = data['ISBN:%s' % self.isbn]
+        except:
+            raise WPDataNotFoundError(self.isbn)
+
+        # map canonical <- records
+        return self.mapper(records)
+
 
 def query(isbn):
     """
